You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by ag...@apache.org on 2017/02/17 15:11:36 UTC

[2/3] ignite git commit: ignite-db-x fix java doc.

ignite-db-x fix java doc.


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/425ae4c4
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/425ae4c4
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/425ae4c4

Branch: refs/heads/ignite-3477
Commit: 425ae4c4df9d621a8b82fc9f0b8a479d597e5c0d
Parents: e486106
Author: Dmitriy Govorukhin <dg...@gridgain.com>
Authored: Fri Feb 17 14:23:32 2017 +0300
Committer: Dmitriy Govorukhin <dg...@gridgain.com>
Committed: Fri Feb 17 14:23:32 2017 +0300

----------------------------------------------------------------------
 .../main/java/org/apache/ignite/cache/PartitionLossPolicy.java  | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/425ae4c4/modules/core/src/main/java/org/apache/ignite/cache/PartitionLossPolicy.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/cache/PartitionLossPolicy.java b/modules/core/src/main/java/org/apache/ignite/cache/PartitionLossPolicy.java
index 585e8df..1391e70 100644
--- a/modules/core/src/main/java/org/apache/ignite/cache/PartitionLossPolicy.java
+++ b/modules/core/src/main/java/org/apache/ignite/cache/PartitionLossPolicy.java
@@ -17,14 +17,15 @@
 
 package org.apache.ignite.cache;
 
-import org.apache.ignite.IgniteCache;
+import java.util.Collection;
+import org.apache.ignite.Ignite;
 
 /**
  * Partition loss policy. Defines how cache will behave in a case when one or more partitions are lost
  * because of a node(s) failure.
  * <p>
  * All <code>*_SAFE</code> policies prevent a user from interaction with partial data in lost partitions until
  * {@link IgniteCache#resetLostPartitions()} method is called. <code>*_ALL</code> policies allow working with
  * partial data in lost partitions.
  * <p>
  * <code>READ_ONLY_*</code> and <code>READ_WRITE_*</code> policies do not automatically change partition state
@@ -17,14 +17,15 @@
  * <p>
  * All <code>*_SAFE</code> policies prevent a user from interaction with partial data in lost partitions until
- * {@link IgniteCache#resetLostPartitions()} method is called. <code>*_ALL</code> policies allow working with
+ * {@link Ignite#resetLostPartitions(Collection)} method is called. <code>*_ALL</code> policies allow working with
  * partial data in lost partitions.
  * <p>